@@ -316,21 +316,20 @@ qx.Class.define("callbackery.ui.plugin.Form", {
             },'getPluginData',this._cfg.name,'allFields',parentFormData,{ currentFormData: this._form.getData()});
         },
         _getUrlData: function () {
-                    let data    = {};
-                    let gotData = false;
-                    let config  = callbackery.data.Config.getInstance();
-                    this._urlFormElements.forEach(urlFormElement => {
-                        let urlValue = config.getUrlConfigValue(urlFormElement.urlKey);
-                        if (urlValue) {
-                            data[urlFormElement.formKey] = urlValue;
-                            // only do it once for the time being
-                            config.removeUrlConfigEntry(urlFormElement.urlKey);
-                            gotData = true;
-                        }
-                    });
-                    return data;
+            let data    = {};
+            let gotData = false;
+            let config  = callbackery.data.Config.getInstance();
+            this._urlFormElements.forEach(urlFormElement => {
+                let urlValue = config.getUrlConfigValue(urlFormElement.urlKey);
+                if (urlValue) {
+                    data[urlFormElement.formKey] = urlValue;
+                    // only do it once for the time being
+                    config.removeUrlConfigEntry(urlFormElement.urlKey);
+                    gotData = true;
                 }
-         },
+            });
+            return data;
+        },
         _loadData: function(mergeUrlData){
             if (!this._form) return;
 
@@ -346,7 +345,7 @@ qx.Class.define("callbackery.ui.plugin.Form", {
             rpc.callAsync(function(data,exc){
                 if (!exc){
                     if (mergeUrlData) {
-                        urlData = this._getUrlData();
+                        let urlData = that._getUrlData();
                         if (!data) {
                             data = urlData;
                         }
